@@ -33,6 +33,9 @@ static const char *bdprefs[] =
     "loop",
     "nbd",
     "sr",
+    "fd",
+    "md",
+    "dm",
     // pmem is usually dax, which doesn't update stats here
     0
 };
